# Python Project

This is a simple package which does addition, subtraction, multiplication and division of two whole numbers.
Made by Aahir Basu.
Currently studying B.Tech EEE at VIT, Vellore.
Registration Number - 22BEE0040